==> qucs-s_24.2.1.orig.tar.gz: qucs-s-24.2.1/qucs/spicecomponents/MOS_SPICE.h <==
/***************************************************************************
                          NMOS_SPICE.h  -  description
                      --------------------------------------
    begin                     : Fri Mar 9 2007
    copyright                 : (C) 2007 by Gunther Kraut
    email                     : gn.kraut@t-online.de
    spice4qucs code added  Sat. 30 May 2015
    copyright                 : (C) 2015 by Mike Brinson
    email                     : mbrin72043@yahoo.co.uk

 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
 #ifndef MOS_SPICE_H
#define MOS_SPICE_H

#include "components/component.h"

class MOS_SPICE : public MultiViewComponent {
public:
  MOS_SPICE();
  ~MOS_SPICE();
  Component* newOne();
  static Element* info(QString&, char* &, bool getNewOne=false);
  static Element* info_NM3pin(QString&, char* &, bool getNewOne=false);
  static Element* info_PM3pin(QString&, char* &, bool getNewOne=false);
  static Element* info_NX3pin(QString&, char* &, bool getNewOne=false);
  static Element* info_PX3pin(QString&, char* &, bool getNewOne=false);
  static Element* info_NX4pin(QString&, char* &, bool getNewOne=false);
  static Element* info_PX4pin(QString&, char* &, bool getNewOne=false);
protected:
  void createSymbol();
  QString netlist();
  QString spice_netlist(bool isXyce = false);
};

#endif // MOS_SPICE_H

==> qucs-s_25.2.0.orig.tar.gz: qucs-s-25.2.0/qucs/spicecomponents/MOS_SPICE.h <==
/***************************************************************************
                          NMOS_SPICE.h  -  description
                      --------------------------------------
    begin                     : Fri Mar 9 2007
    copyright                 : (C) 2007 by Gunther Kraut
    email                     : gn.kraut@t-online.de
    spice4qucs code added  Sat. 30 May 2015
    copyright                 : (C) 2015 by Mike Brinson
    email                     : mbrin72043@yahoo.co.uk

 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
 #ifndef MOS_SPICE_H
#define MOS_SPICE_H

#include "components/component.h"

class MOS_SPICE : public MultiViewComponent {
public:
  MOS_SPICE();
  ~MOS_SPICE();
  Component* newOne();
  static Element* info(QString&, char* &, bool getNewOne=false);
  static Element* info_NM3pin(QString&, char* &, bool getNewOne=false);
  static Element* info_PM3pin(QString&, char* &, bool getNewOne=false);
  static Element* info_NX3pin(QString&, char* &, bool getNewOne=false);
  static Element* info_PX3pin(QString&, char* &, bool getNewOne=false);
  static Element* info_NX4pin(QString&, char* &, bool getNewOne=false);
  static Element* info_PX4pin(QString&, char* &, bool getNewOne=false);

protected:
  void createSymbol();
  QString netlist();
  QString spice_netlist(spicecompat::SpiceDialect dialect = spicecompat::SPICEDefault);
  virtual QString cdl_netlist();
};

#endif // MOS_SPICE_H
